Search.setIndex({docnames:["index","issue_template"],envversion:53,filenames:["index.md","issue_template.md"],objects:{},objnames:{},objtypes:{},terms:{"return":0,"true":0,For:0,The:0,These:0,With:0,abl:0,abov:0,addus:0,all:0,also:0,android:0,ani:0,api:0,avail:0,base:0,behind:0,better:0,bin:0,browser:0,can:0,chang:0,charact:0,clementin:0,clone:0,cmmand:0,com:0,complet:0,compos:0,conf:0,config:0,contain:0,conveni:0,copi:0,correctli:0,creat:0,data:0,databas:0,defin:0,depend:0,deploy:0,desktop:0,detail:0,devel:0,directori:0,dist:0,distro:0,dockerfil:0,doe:0,doesn:0,domain:0,download:0,drop:0,dsub:0,each:0,easili:0,edit:0,etc:0,exampl:0,exist:0,file:0,fit:0,follow:0,forward:0,free:0,gear:0,getartist:0,github:0,gnu:0,gpl:0,handl:0,have:0,here:0,host:0,how:0,html:0,http2:0,http:0,imag:0,ini:0,init:0,instanc:0,isu:0,its:0,itself:0,jamstash:0,known:0,less:0,librari:0,like:0,line:0,linux:0,listen:0,load:0,local:0,localhost:0,locat:0,mai:0,main:0,make:0,makefil:0,mishmash:0,more:0,mount:0,multipl:0,music:0,music_dir:0,must:0,name:0,need:0,nginx:0,normal:0,one:0,onli:0,org:0,otherwis:0,out:0,own:0,pass:0,path:0,per:0,picki:0,pip3:0,plai:0,point:0,portion:0,postgr:0,postgresql:0,print:0,process:0,product:0,proto:0,proxi:0,proxy_add_x_forwarded_for:0,proxy_buff:0,proxy_buffer_s:0,proxy_pass:0,proxy_read_timeout:0,proxy_set_head:0,real:0,redirect:0,refer:0,reload:0,remote_addr:0,remov:0,replac:0,request_uri:0,requir:0,resourc:0,revers:0,scheme:0,sec1:0,see:0,serv:0,server:0,server_nam:0,set:0,setup:0,should:0,show:0,shown:0,simplifi:0,site:0,some:0,someth:0,song:0,sort:0,specif:0,specifi:0,sqlalchemi:0,sqlite:0,ssl:0,start:0,strive:0,subson:0,sudo:0,sure:0,sync:0,systemctl:0,tag:0,target:0,tester:0,them:0,thi:0,those:0,toward:0,trail:0,tsquillario:0,tweak:0,under:0,updat:0,url:0,usabl:0,use:0,used:0,using:0,veri:0,volum:0,well:0,whatev:0,wish:0,without:0,work:0,would:0,www:0,yml:0,you:0,your:0},titles:["Status","Expected behavior"],titleterms:{TLS:0,about:0,actual:1,adjust:0,behavior:1,build:0,client:0,configur:0,develop:0,docker:0,expect:1,from:0,instal:0,licens:0,manual:0,pip:0,pypi:0,reproduc:1,run:0,servic:0,sourc:0,statu:0,step:1,support:0,system:0,test:0,unson:0,via:0,web:0}})